@@ -1,16 +1,18 @@
 #' @import parmigene
+#' @importFrom infotheo discretize mutinformation
 #' @importFrom igraph graph.adjacency simplify
+#' @importFrom igraph igraph_opt layout.circle
 NULL
 
-#' Plots mutual information network (using mrnet algorithm) connection using the parmigene package
+#' Plots mutual information network (mrnet algorithm) connection using the parmigene package. Mutual information calculated with infotheo package.
 #' @param dataMatrix data matrix with first column being the sample ID
 #' @param threshold the number of edges to draw for each subpopulation mutual information network
 
 MINetworkPlot_topEdges<-function(dataMatrix, threshold){
-  igraph_opt<-NULL
-  layout.circle<-NULL
+
+  dat<-discretize(dataMatrix)
+  dataMatrix_mi<-mutinformation(dat, method="emp")
   
-  dataMatrix_mi<-knnmi.all(t(dataMatrix))
   dataMatrix_net<-mrnet(dataMatrix_mi)
   
   filterLevel<-dataMatrix_net[order(dataMatrix_net, decreasing=TRUE)][threshold]
